==> nextcloud-30.0.12.tgz: nextcloud/apps/systemtags/l10n/sk.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systémový štítok %1$s bol pridaný systémom",
    "Added system tag {systemtag}" : "Pridaný systémový štítok {systemtag}",
    "Added system tag %1$s" : "Pridaný systémový štítok %1$s",
    "%1$s added system tag %2$s" : "%1$s pridal(a) systémový štítok %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridal(a) systémový štítok {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítok %1$s bol odstránený systémom",
    "Removed system tag {systemtag}" : "Odstránený systémový štítok {systemtag}",
    "Removed system tag %1$s" : "Odstránený systémový štítok %1$s",
    "%1$s removed system tag %2$s" : "%1$s odstránil(a) systémový štítok %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You created system tag %1$s" : "Vytvorili ste systémový štítok %1$s",
    "You created system tag {systemtag}" : "Vytvorili ste systémový štítok {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvoril systémový štítok %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvoril(a) systémový štítok {systemtag}",
    "You deleted system tag %1$s" : "Zmazali ste systémový štítok %1$s",
    "You deleted system tag {systemtag}" : "Odstránili ste systémový štítok {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s zmazal(a) systémový štítok %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali ste systémový štítok %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali ste systémový štítok {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítok %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítok {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítok %2$s bol sytémom pridaný do %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Súboru {file} bol systémom pridaný systémový štítok {systemtag}",
    "You added system tag %2$s to %1$s" : "Pridali ste systémový štítok %2$s na %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} ste pridali systémový štítok {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s pridal(a) systémový štítok %3$s",
    "{actor} added system tag {systemtag} to {file}" : " {actor} k {file} pridal(a) systémový štítok {systemtag}",
    "System tag %2$s was removed from %1$s by the system" : "Systémový štítok %2$s bol z %1$s odstránený systémom",
    "System tag {systemtag} was removed from {file} by the system" : "Systémový štítok {systemtag} bol z {file} odstránený systémom",
    "You removed system tag %2$s from %1$s" : "Z %2$s ste odstránili systémový štítok %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} ste odstránili systémový štítok {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstránil(a) systémový štítok %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstránil(a) systémový štítok {systemtag} z {file}",
    "%s (restricted)" : "%s (obmedzené)",
    "%s (invisible)" : "%s (neviditeľné)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> súboru boli upravené",
    "Files" : "Súbory",
    "Tags" : "Štítky",
    "All tagged %s …" : "Všetky označené %s …",
    "tagged %s" : "označené %s",
    "Collaborative tags" : "Štítky pre spoluprácu",
    "Collaborative tagging functionality which shares tags among people." : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi ľuďmi.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi ľuďmi. Skvelé pre tímy.\n\t (Ak ste poskytovateľom inštalácie pre viacero subjektov, odporúča sa túto aplikáciu deaktivovať, pretože štítky sú zdieľané.)",
    "Public" : "Verejné",
    "Restricted" : "Obmedzené",
    "Invisible" : "Neviditeľné",
    "Created tag" : "Vytvorený štítok",
    "Failed to create tag" : "Nepodarilo sa vytvoriť štítok",
    "Updated tag" : "Aktualizovaný štítok",
    "Failed to update tag" : "Nepodarilo sa aktualizovať štítok",
    "Deleted tag" : "Zmazaný štítok",
    "Failed to delete tag" : "Nepodarilo sa vymazať štítok",
    "Create or edit tags" : "Vytvoriť alebo upraviť štítky",
    "Search for a tag to edit" : "Vyhľadať štítok pre úpravu.",
    "Collaborative tags …" : "Štítky pre spoluprácu ...",
    "No tags to select" : "Žiadne štítky na výber",
    "Tag name" : "Názov štítku",
    "Tag level" : "Úroveň štítku",
    "Create" : "Vytvoriť",
    "Update" : "Aktualizovať",
    "Delete" : "Zmazať",
    "Reset" : "Vynulovať",
    "Loading …" : "Načítavam …",
    "{displayName} (hidden)" : "{displayName}(skrytý)",
    "{displayName} (restricted)" : "{displayName}(obmedzený)",
    "Failed to apply tags changes" : "Nepodarilo sa aplikovať zmeny štítkov",
    "File tags modification canceled" : "Zmena štítkov súboru bola zrušená",
    "Manage tags" : "Spravovať štítky",
    "Applying tags changes…" : "Aplikujem zmeny štítkov...",
    "Search or create tag" : "Vyhľadať alebo vytvoriť štítok",
    "Change tag color" : "Zmeniť farbu štítkov",
    "Create new tag" : "Vytvoriť nový štítok",
    "Select or create tags to apply to all selected files" : "Vybrať alebo vytvoriť štítok a aplikovať na všetky vybrané súbory",
    "Cancel" : "Zrušiť",
    "Apply changes" : "Aplikovať zmeny",
    "Failed to load tags" : "Nepodarilo sa načítať štítky",
    "Failed to load selected tags" : "Nepodarilo sa načítať vytvorený štítok",
    "Failed to select tag" : "Nepodarilo sa vybrať štítok",
    "System admin disabled tag creation. You can only use existing ones." : "Systémový administrátor zakázal vytváranie štítkov. Môžete použiť iba už existujúce",
    "Loading collaborative tags …" : "Načítavanie štítkov pre spoluprácu ...",
    "Search or create collaborative tags" : "Hľadajte alebo vytvorte  štítky pre spoluprácu",
    "No tags to select, type to create a new tag" : "Žiadne štítky neboli vybraté, začnite písať pre vytvorenie ďalších.",
    "Unable to update setting" : "Nie je možné upraviť nastavenie",
    "System tag creation is now restricted to administrators" : "Vytváranie systémových štítkov je teraz obmedzené iba na administrátorov",
    "System tag creation is now allowed for everybody" : "Vytváranie systémových štítkov je teraz povolené pre všetkých",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pre spoluprácu sú k dispozícii pre všetkých používateľov. Obmedzené štítky sú viditeľné pre používateľov, ale nedajú sa priradiť. Neviditeľné značky sú určené na interné použitie, pretože používatelia ich nemôžu vidieť ani priradiť.",
    "Assigned collaborative tags" : "Priradené štítky pre spoluprácu",
    "Open in Files" : "Otvoriť v súboroch",
    "List of tags and their associated files and folders." : "Zoznam štítkov a ich priradené súbory a priečinky.",
    "No tags found" : "Štítky sa nenašli",
    "Tags you have created will show up here." : "Štítky, ktoré ste vytvorili sa zobrazia tu.",
    "Failed to load tag" : "Chyba pri načítavaní štítku",
    "Failed to load last used tags" : "Nepodarilo sa načítať posledné použité štítky",
    "Missing \"Content-Location\" header" : "Chýbajúca hlavička \"Content-Location\"",
    "A tag with the same name already exists" : "Štítok s rovnakým menom už existuje",
    "Failed to load tags for file" : "Nepodarilo sa načítať štítky pre súbor",
    "Failed to set tag for file" : "Nepodarilo sa nastaviť štítok pre súbor",
    "Failed to delete tag for file" : "Nepodarilo sa odstrániť štítok pre súbor"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-31.0.4.tgz: nextcloud/apps/systemtags/l10n/sk.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Systémový štítok %1$s bol pridaný systémom",
    "Added system tag {systemtag}" : "Pridaný systémový štítok {systemtag}",
    "Added system tag %1$s" : "Pridaný systémový štítok %1$s",
    "%1$s added system tag %2$s" : "%1$s pridal(a) systémový štítok %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridal(a) systémový štítok {systemtag}",
    "System tag %1$s removed by the system" : "Systémový štítok %1$s bol odstránený systémom",
    "Removed system tag {systemtag}" : "Odstránený systémový štítok {systemtag}",
    "Removed system tag %1$s" : "Odstránený systémový štítok %1$s",
    "%1$s removed system tag %2$s" : "%1$s odstránil(a) systémový štítok %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You created system tag %1$s" : "Vytvorili ste systémový štítok %1$s",
    "You created system tag {systemtag}" : "Vytvorili ste systémový štítok {systemtag}",
    "%1$s created system tag %2$s" : "%1$s vytvoril systémový štítok %2$s",
    "{actor} created system tag {systemtag}" : "{actor} vytvoril(a) systémový štítok {systemtag}",
    "You deleted system tag %1$s" : "Zmazali ste systémový štítok %1$s",
    "You deleted system tag {systemtag}" : "Odstránili ste systémový štítok {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s zmazal(a) systémový štítok %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} odstránil(a) systémový štítok {systemtag}",
    "You updated system tag %2$s to %1$s" : "Aktualizovali ste systémový štítok %2$s na %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Aktualizovali ste systémový štítok {oldsystemtag} na {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval(a) systémový štítok %3$s na %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} aktualizoval(a) systémový štítok {oldsystemtag} na {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Systémový štítok %2$s bol sytémom pridaný do %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Súboru {file} bol systémom pridaný systémový štítok {systemtag}",
    "You added system tag %2$s to %1$s" : "Pridali ste systémový štítok %2$s na %1$s",
    "You added system tag {systemtag} to {file}" : "K {file} ste pridali systémový štítok {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s k %2$s pridal(a) systémový štítok %3$s",
    "{actor} added system tag {systemtag} to {file}" : " {actor} k {file} pridal(a) systémový štítok {systemtag}",
    "System tag %2$s was removed from %1$s by the system" : "Systémový štítok %2$s bol z %1$s odstránený systémom",
    "System tag {systemtag} was removed from {file} by the system" : "Systémový štítok {systemtag} bol z {file} odstránený systémom",
    "You removed system tag %2$s from %1$s" : "Z %2$s ste odstránili systémový štítok %1$s",
    "You removed system tag {systemtag} from {file}" : "Z {file} ste odstránili systémový štítok {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s odstránil(a) systémový štítok %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} odstránil(a) systémový štítok {systemtag} z {file}",
    "%s (restricted)" : "%s (obmedzené)",
    "%s (invisible)" : "%s (neviditeľné)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové štítky</strong> súboru boli upravené",
    "Files" : "Súbory",
    "Tags" : "Štítky",
    "All tagged %s …" : "Všetky označené %s …",
    "tagged %s" : "označené %s",
    "Collaborative tags" : "Štítky pre spoluprácu",
    "Collaborative tagging functionality which shares tags among people." : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi ľuďmi.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi ľuďmi. Skvelé pre tímy.\n\t (Ak ste poskytovateľom inštalácie pre viacero subjektov, odporúča sa túto aplikáciu deaktivovať, pretože štítky sú zdieľané.)",
    "Public" : "Verejné",
    "Restricted" : "Obmedzené",
    "Invisible" : "Neviditeľné",
    "Created tag" : "Vytvorený štítok",
    "Failed to create tag" : "Nepodarilo sa vytvoriť štítok",
    "Updated tag" : "Aktualizovaný štítok",
    "Failed to update tag" : "Nepodarilo sa aktualizovať štítok",
    "Deleted tag" : "Zmazaný štítok",
    "Failed to delete tag" : "Nepodarilo sa vymazať štítok",
    "Create or edit tags" : "Vytvoriť alebo upraviť štítky",
    "Search for a tag to edit" : "Vyhľadať štítok pre úpravu.",
    "Collaborative tags …" : "Štítky pre spoluprácu ...",
    "No tags to select" : "Žiadne štítky na výber",
    "Tag name" : "Názov štítku",
    "Tag level" : "Úroveň štítku",
    "Create" : "Vytvoriť",
    "Update" : "Aktualizovať",
    "Delete" : "Zmazať",
    "Reset" : "Vynulovať",
    "Loading …" : "Načítavam …",
    "{displayName} (hidden)" : "{displayName}(skrytý)",
    "{displayName} (restricted)" : "{displayName}(obmedzený)",
    "Failed to apply tags changes" : "Nepodarilo sa aplikovať zmeny štítkov",
    "File tags modification canceled" : "Zmena štítkov súboru bola zrušená",
    "Manage tags" : "Spravovať štítky",
    "Applying tags changes…" : "Aplikujem zmeny štítkov...",
    "Search or create tag" : "Vyhľadať alebo vytvoriť štítok",
    "Change tag color" : "Zmeniť farbu štítkov",
    "Create new tag" : "Vytvoriť nový štítok",
    "Select or create tags to apply to all selected files" : "Vybrať alebo vytvoriť štítok a aplikovať na všetky vybrané súbory",
    "Cancel" : "Zrušiť",
    "Apply changes" : "Aplikovať zmeny",
    "Failed to load tags" : "Nepodarilo sa načítať štítky",
    "Failed to load selected tags" : "Nepodarilo sa načítať vytvorený štítok",
    "Failed to select tag" : "Nepodarilo sa vybrať štítok",
    "System admin disabled tag creation. You can only use existing ones." : "Systémový administrátor zakázal vytváranie štítkov. Môžete použiť iba už existujúce",
    "Loading collaborative tags …" : "Načítavanie štítkov pre spoluprácu ...",
    "Search or create collaborative tags" : "Hľadajte alebo vytvorte  štítky pre spoluprácu",
    "No tags to select, type to create a new tag" : "Žiadne štítky neboli vybraté, začnite písať pre vytvorenie ďalších.",
    "Unable to update setting" : "Nie je možné upraviť nastavenie",
    "System tag creation is now restricted to administrators" : "Vytváranie systémových štítkov je teraz obmedzené iba na administrátorov",
    "System tag creation is now allowed for everybody" : "Vytváranie systémových štítkov je teraz povolené pre všetkých",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pre spoluprácu sú k dispozícii pre všetkých používateľov. Obmedzené štítky sú viditeľné pre používateľov, ale nedajú sa priradiť. Neviditeľné značky sú určené na interné použitie, pretože používatelia ich nemôžu vidieť ani priradiť.",
    "Assigned collaborative tags" : "Priradené štítky pre spoluprácu",
    "Open in Files" : "Otvoriť v súboroch",
    "List of tags and their associated files and folders." : "Zoznam štítkov a ich priradené súbory a priečinky.",
    "No tags found" : "Štítky sa nenašli",
    "Tags you have created will show up here." : "Štítky, ktoré ste vytvorili sa zobrazia tu.",
    "Failed to load tag" : "Chyba pri načítavaní štítku",
    "Failed to load last used tags" : "Nepodarilo sa načítať posledné použité štítky",
    "Missing \"Content-Location\" header" : "Chýbajúca hlavička \"Content-Location\"",
    "A tag with the same name already exists" : "Štítok s rovnakým menom už existuje",
    "Failed to load tags for file" : "Nepodarilo sa načítať štítky pre súbor",
    "Failed to set tag for file" : "Nepodarilo sa nastaviť štítok pre súbor",
    "Failed to delete tag for file" : "Nepodarilo sa odstrániť štítok pre súbor",
    "This file has the tag {tag}" : "Tento súbor má štítok {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tento súbor má štítky {firstTags} a {lastTag}"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
